@@ -4,7 +4,7 @@
  * 		Query deparser for mysql_fdw
  *
  * Portions Copyright (c) 2012-2014, PostgreSQL Global Development Group
- * Portions Copyright (c) 2004-2024, EnterpriseDB Corporation.
+ * Portions Copyright (c) 2004-2025, EnterpriseDB Corporation.
  *
  * IDENTIFICATION
  * 		deparse.c
@@ -358,20 +358,12 @@ mysql_deparse_select_sql(List *tlist, List **retrieved_attrs,
 		 * Core code already has some lock on each rel being planned, so we
 		 * can use NoLock here.
 		 */
-#if PG_VERSION_NUM < 130000
-		rel = heap_open(rte->relid, NoLock);
-#else
 		rel = table_open(rte->relid, NoLock);
-#endif
 
 		mysql_deparse_target_list(buf, root, foreignrel->relid, rel,
 								  fpinfo->attrs_used, retrieved_attrs);
 
-#if PG_VERSION_NUM < 130000
-		heap_close(rel, NoLock);
-#else
 		table_close(rel, NoLock);
-#endif
 	}
 }
 
@@ -1031,11 +1023,7 @@ mysql_deparse_array_ref(SubscriptingRef *node, deparse_expr_cxt *context)
 		{
 			deparseExpr(lfirst(lowlist_item), context);
 			appendStringInfoChar(buf, ':');
-#if PG_VERSION_NUM < 130000
-			lowlist_item = lnext(lowlist_item);
-#else
 			lowlist_item = lnext(node->reflowerindexpr, lowlist_item);
-#endif
 		}
 		deparseExpr(lfirst(uplist_item), context);
 		appendStringInfoChar(buf, ']');
@@ -1543,6 +1531,14 @@ foreign_expr_walker(Node *node, foreign_glob_cxt *glob_cxt,
 			{
 				Param	   *p = (Param *) node;
 
+				/*
+				 * Bail out on planner internal params.  We could perhaps pass
+				 * them to the remote server as regular params, but we don't
+				 * have the machinery to do that at the moment.
+				 */
+				if (p->paramkind != PARAM_EXTERN)
+					return false;
+
 				/*
 				 * Collation rule is same as for Consts and non-foreign Vars.
 				 */
@@ -2116,11 +2112,7 @@ mysql_deparse_from_expr_for_rel(StringInfo buf, PlannerInfo *root,
 		 * Core code already has some lock on each rel being planned, so we
 		 * can use NoLock here.
 		 */
-#if PG_VERSION_NUM < 130000
-		rel = heap_open(rte->relid, NoLock);
-#else
 		rel = table_open(rte->relid, NoLock);
-#endif
 
 		mysql_deparse_relation(buf, rel);
 
@@ -2133,11 +2125,7 @@ mysql_deparse_from_expr_for_rel(StringInfo buf, PlannerInfo *root,
 			appendStringInfo(buf, " %s%d", REL_ALIAS_PREFIX,
 							 foreignrel->relid);
 
-#if PG_VERSION_NUM < 130000
-		heap_close(rel, NoLock);
-#else
 		table_close(rel, NoLock);
-#endif
 	}
 	return;
 }
