@@ -4,7 +4,7 @@
  * 		Foreign-data wrapper for remote MySQL servers
  *
  * Portions Copyright (c) 2012-2014, PostgreSQL Global Development Group
- * Portions Copyright (c) 2004-2024, EnterpriseDB Corporation.
+ * Portions Copyright (c) 2004-2025, EnterpriseDB Corporation.
  *
  * IDENTIFICATION
  * 		mysql_fdw.h
@@ -73,11 +73,7 @@
 #define mysql_num_rows (*_mysql_num_rows)
 
 /* Macro for list API backporting. */
-#if PG_VERSION_NUM < 130000
-#define mysql_list_concat(l1, l2) list_concat(l1, list_copy(l2))
-#else
 #define mysql_list_concat(l1, l2) list_concat((l1), (l2))
-#endif
 
 /*
  * Options structure to store the MySQL
